@@ -36,12 +36,6 @@ class R:
     def put(cls, id=None, data=None, *args, **kwargs):
         if id:
             cls.save(id, data)
-        else:
-            cls.update(*args, **kwargs)
-
-    @classmethod
-    def update(cls, *args, **kwargs):
-        pass 
 
     @classmethod
     def delete(cls, id: int):
