@@ -1,4 +1,4 @@
-from zmemory import Memory
+from xl_memory import Memory
 from flask import current_app
 
 
